Projects per language
=====================

This page lists all projects found by searching 'gnucash' on github (generated on 2017-10-08 20:52:39) excluding mirrors of the gnucash repository. Projects with a '\*' are projectsthat have not been updated since 12 months.

+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     Language                     |                  # of projects                   |     # of projects updated in last 12 months      |
+==================================================+==================================================+==================================================+
|                  :ref:`Python`                   |                        94                        |                        45                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Unknown`                  |                        30                        |                        13                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Perl`                    |                        26                        |                        11                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Shell`                   |                        23                        |                        10                        |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`JavaScript`                 |                        18                        |                        9                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Java`                    |                        26                        |                        8                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Ruby`                    |                        12                        |                        7                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`PHP`                    |                        12                        |                        4                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Scheme`                   |                        13                        |                        4                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Go`                     |                        3                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`HTML`                    |                        4                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Perl 6`                   |                        2                         |                        2                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C++`                    |                        2                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|             :ref:`Jupyter Notebook`              |                        3                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     :ref:`R`                     |                        2                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`SQLPL`                   |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Scala`                   |                        3                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Swift`                   |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Tcl`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                :ref:`TypeScript`                 |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|               :ref:`Visual Basic`                |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`XSLT`                    |                        1                         |                        1                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`Awk`                    |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                     :ref:`C`                     |                        2                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`C#`                     |                        4                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|               :ref:`CoffeeScript`                |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                 :ref:`Cucumber`                  |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Diff`                    |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                    :ref:`F#`                     |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|              :ref:`Gettext Catalog`              |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Groovy`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                  :ref:`Haskell`                  |                        2                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`PLSQL`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+
|                   :ref:`Perl6`                   |                        1                         |                        0                         |
+--------------------------------------------------+--------------------------------------------------+--------------------------------------------------+

.. _Python:

Python
------

\* `AceMoney-to-GnuCash <https://github.com/lowvoltage/AceMoney-to-GnuCash>`__ by lowvoltage (last updated on  2015-01-11)
	A quick and dirty script to convert an AceMoney .XML into a GnuCash .XML
\* `alchemy <https://github.com/zmoog/alchemy>`__ by zmoog (last updated on  2016-05-08)
	A very simple Gnucash-inspired web application
`BankCSVtoQif <https://github.com/niknow/BankCSVtoQif>`__ by niknow (last updated on  2017-02-07)
	Converts csv files from a bank to qif and replaces descriptions and target accounts according to predefined customizable rules along the way. Intended to work as a tool for gnucash.
`django-openbudget <https://github.com/evandavey/django-openbudget>`__ by evandavey (last updated on  2017-01-20)
	Simple django-based personal budgeting app that sources data from GNUCash sqlite data files
\* `DnbNor2qif <https://github.com/djiti/DnbNor2qif>`__ by djiti (last updated on  2013-08-26)
	Turning DnbNor CSV files into GNUCash-compatible QIF files
\* `dropcopy <https://github.com/juniorbl/dropcopy>`__ by juniorbl (last updated on  2015-10-25)
	A simple tool for GNOME to copy a given GnuCash file to a local dropbox directory whenever it is saved.
`edoBank2Qif <https://github.com/engdan77/edoBank2Qif>`__ by engdan77 (last updated on  2017-08-18)
	Program for processing XML/XLS bank account exports into QIF-format supported by e.g. GnuCash developed in Python
\* `financial_forecast <https://github.com/skullspace/financial_forecast>`__ by skullspace (last updated on  2016-02-06)
	A script to take in our Gnucash books and output a CSV with some historical and forecasted data
\* `flux <https://github.com/marcotmarcot/flux>`__ by marcotmarcot (last updated on  2015-04-23)
	Create a monthly flux report from a gnucash file
\* `gcconv <https://github.com/AloisMahdal/gcconv>`__ by AloisMahdal (last updated on  2016-08-01)
	GnuCash import helper
`gcimport <https://github.com/nblock/gcimport>`__ by nblock (last updated on  2017-05-29)
	Convert various input files (csv, txt) to csv files that can be easily parsed with GnuCash.
`gcinvoice <https://github.com/ngiger/gcinvoice>`__ by ngiger (last updated on  2017-04-06)
	GnuCash to Lates (see http://www.smoerz.org/gcinvoice/) + my personal templates
\* `gnc_budget_scroll <https://github.com/mateuszzz88/gnc_budget_scroll>`__ by mateuszzz88 (last updated on  2016-09-18)
	This is a converter for gnucash bugdet report. It will create html with the same content, but table will be scrollable in such way, that headers (date, account name) are visible
\* `gnc_privat24 <https://github.com/gentoo90/gnc_privat24>`__ by gentoo90 (last updated on  2015-03-29)
	Imports Privat24 statements to Gnucash book
\* `gnucash-account2template <https://github.com/EvansMike/gnucash-account2template>`__ by EvansMike (last updated on  2015-09-03)
	Make a GnuCash account template from an exported account
`gnucash-bridge <https://github.com/dbellettini/gnucash-bridge>`__ by dbellettini (last updated on  2017-02-18)
	Expose GnuCash as a microservice
\* `gnucash-budgerow- <https://github.com/dlex/gnucash-budgerow->`__ by dlex (last updated on  2016-02-05)
	Predictive budgeter for GnuCash
`gnucash-budget <https://github.com/chrisbrasington/gnucash-budget>`__ by chrisbrasington (last updated on  2017-01-06)
	Minimalist budget reporting.
`gnucash-categorizer <https://github.com/seddonym/gnucash-categorizer>`__ by seddonym (last updated on  2017-04-14)
	(No description available)
\* `gnucash-cfdi <https://github.com/sebastianavina/gnucash-cfdi>`__ by sebastianavina (last updated on  2016-09-09)
	Proyecto que timbra facturas de gnucash por medio de facturacion moderna.
\* `gnucash-expense-report <https://github.com/QuLogic/gnucash-expense-report>`__ by QuLogic (last updated on  2015-01-29)
	(No description available)
`gnucash-fiximports <https://github.com/sandeepmukherjee/gnucash-fiximports>`__ by sandeepmukherjee (last updated on  2017-01-22)
	Change target accounts of imported gnucash transactions
`gnucash-fiximports <https://github.com/HappyPeng2x/gnucash-fiximports>`__ by HappyPeng2x (last updated on  2017-09-24)
	Additional developments on the original gnucash-fiximports
`gnucash-import <https://github.com/manzato/gnucash-import>`__ by manzato (last updated on  2017-09-03)
	Imports transactions from a CSV file and places them to the appropriate account depending on a set of rules
\* `gnucash-importers <https://github.com/rtucker/gnucash-importers>`__ by rtucker (last updated on  2016-07-01)
	gnucash importer scripts for Interlock Rochester financial foo
`gnucash-latex <https://github.com/mwellnitz/gnucash-latex>`__ by mwellnitz (last updated on  2017-09-27)
	Create good looking invoices for gnucash using latex and python
`gnucash-latex-koma <https://github.com/jappeace/gnucash-latex-koma>`__ by jappeace (last updated on  2017-02-18)
	 Create good looking invoices for gnucash using latex/koma and python 
\* `gnucash-ofx-brokerage <https://github.com/7max/gnucash-ofx-brokerage>`__ by 7max (last updated on  2013-10-20)
	GnuCash OFX importer that handles brokerages, ie stocks, mutual funds, optios
`gnucash-ofx-export <https://github.com/hoffie/gnucash-ofx-export>`__ by hoffie (last updated on  2017-05-25)
	Selectively export GnuCash transactions into OFX
\* `gnucash-pyquotehist <https://github.com/tfree87/gnucash-pyquotehist>`__ by tfree87 (last updated on  2015-07-26)
	A simple python script which imports historical price quotes from yahoo into Gnucash via the command line without the need for Perl Finance::QuoteHist. Based on Peter Holtermann's quotes_hist script
\* `Gnucash-Python-Example <https://github.com/petarkabashki/Gnucash-Python-Example>`__ by petarkabashki (last updated on  2015-12-02)
	Example python script for importing data into Gnucash
\* `gnucash-python-free <https://github.com/tbhartman/gnucash-python-free>`__ by tbhartman (last updated on  2014-08-23)
	(No description available)
\* `GNUCash-Python-Scripts <https://github.com/relyt29/GNUCash-Python-Scripts>`__ by relyt29 (last updated on  2016-07-04)
	various python scripts to add to gnucash functionality
`gnucash-qif-import <https://github.com/hjacobs/gnucash-qif-import>`__ by hjacobs (last updated on  2017-09-24)
	GnuCash Python helper script to import transactions from QIF text files into GnuCash's own file format
\* `gnucash-reporting <https://github.com/MeerkatLabs/gnucash-reporting>`__ by MeerkatLabs (last updated on  2015-10-30)
	Simple reporting framework for fetching data out of gnucash files for display in a viewer.
`gnucash-rest <https://github.com/loftx/gnucash-rest>`__ by loftx (last updated on  2017-02-05)
	A Python based REST framework for the Gnucash accounting application
`GNUCash-scripts <https://github.com/spartha80/GNUCash-scripts>`__ by spartha80 (last updated on  2016-12-22)
	Simple Python scripts to convert Bank statements to QIF format
\* `gnucash-society <https://github.com/hendrikvanantwerpen/gnucash-society>`__ by hendrikvanantwerpen (last updated on  2013-11-02)
	Support application for societies based on GnuCash
`gnucash-stock-portfolio <https://github.com/hjacobs/gnucash-stock-portfolio>`__ by hjacobs (last updated on  2017-08-19)
	GnuCash Python utilities to manage a stock portfolio
`gnucash-to-beancount <https://github.com/henriquebastos/gnucash-to-beancount>`__ by henriquebastos (last updated on  2017-03-12)
	Gnucash to Beancount Converter.
\* `gnucash-tools <https://github.com/dahnielson/gnucash-tools>`__ by dahnielson (last updated on  2013-11-30)
	Tools for working with GnuCash
\* `gnucash-tools <https://github.com/yanivmo/gnucash-tools>`__ by yanivmo (last updated on  2016-03-16)
	GnuCash interoperability scripts
\* `gnucash-tools <https://github.com/cnuahs/gnucash-tools>`__ by cnuahs (last updated on  2016-07-26)
	Command line tools for use with Gnucash (http://gnucash.org/).
\* `gnucash-toolset <https://github.com/cirrax/gnucash-toolset>`__ by cirrax (last updated on  2015-03-04)
	Access and manipulate gnucash data.
\* `gnucash-util <https://github.com/bstpierre/gnucash-util>`__ by bstpierre (last updated on  2015-02-16)
	Utility scripts using GnuCash python bindings
`gnucash-utilities <https://github.com/sdementen/gnucash-utilities>`__ by sdementen (last updated on  2016-12-22)
	Set of python scripts to work with GnuCash books
\* `gnucash-utils <https://github.com/AndreasHeger/gnucash-utils>`__ by AndreasHeger (last updated on  2015-05-20)
	utility scripts for gnucash
\* `gnucash-xml-split <https://github.com/fefe982/gnucash-xml-split>`__ by fefe982 (last updated on  2014-08-26)
	Split GnuCash XML files into files containing transaction in a certain period (e.g. a year)
\* `gnucash2iif <https://github.com/pawl/gnucash2iif>`__ by pawl (last updated on  2013-08-18)
	Converts a Gnucash general ledger to an IIF file (for quickbooks)
`gnucash_autobudget <https://github.com/rmoehn/gnucash_autobudget>`__ by rmoehn (last updated on  2017-03-06)
	Automatically adjust GnuCash transactions for envelope budgeting (discontinued)
\* `gnucash_balance_report <https://github.com/tbhartman/gnucash_balance_report>`__ by tbhartman (last updated on  2014-07-24)
	get balance report from gnucash file
`gnucash_budget <https://github.com/dschwen/gnucash_budget>`__ by dschwen (last updated on  2017-01-22)
	Tools to work with a GnuCash database
`gnucash_converter <https://github.com/boszkie/gnucash_converter>`__ by boszkie (last updated on  2017-05-12)
	python script to convert rabobank (nl) csv format to gnuCash csv import format
\* `gnucash_django <https://github.com/RobFisher/gnucash_django>`__ by RobFisher (last updated on  2014-04-09)
	GnuCash Web Interface using Django.
\* `gnucash_explorer <https://github.com/peap/gnucash_explorer>`__ by peap (last updated on  2014-04-27)
	Another option for exploring your gnucash database
\* `gnucash_exports <https://github.com/jjuanda/gnucash_exports>`__ by jjuanda (last updated on  2014-01-13)
	GnuCash export scripts into several DBs/file formats
\* `gnucash_lbb_amazon <https://github.com/elezar/gnucash_lbb_amazon>`__ by elezar (last updated on  2015-12-28)
	Amazon Credit Card CSV pre-processor for GNUCash
\* `gnucash_ofx <https://github.com/gevious/gnucash_ofx>`__ by gevious (last updated on  2015-03-26)
	Convert gnucash xml file to set of OFX files
`gnucash_python <https://github.com/davidjo/gnucash_python>`__ by davidjo (last updated on  2016-10-31)
	gnucash report writing in python
\* `gnucash_scripts <https://github.com/vrih/gnucash_scripts>`__ by vrih (last updated on  2013-09-10)
	(No description available)
\* `gnucashdjango <https://github.com/ugedo/gnucashdjango>`__ by ugedo (last updated on  2016-07-04)
	(No description available)
\* `GnuCashImporter <https://github.com/sphaero/GnuCashImporter>`__ by sphaero (last updated on  2015-03-08)
	Simple console tool to import mt940 file and match transactions to GnuCash accounts
`gnucashreconcile <https://github.com/seddonym/gnucashreconcile>`__ by seddonym (last updated on  2017-03-29)
	(No description available)
`gnucashreport <https://github.com/partizand/gnucashreport>`__ by partizand (last updated on  2017-05-15)
	Python library for get reports from GnuCash to xlsx files
`GnucashReporting <https://github.com/sholly/GnucashReporting>`__ by sholly (last updated on  2017-06-27)
	Python/Flask backend for gnucash reports
\* `gnucashreports <https://github.com/youngchul/gnucashreports>`__ by youngchul (last updated on  2015-07-08)
	(No description available)
`gnuCashTools <https://github.com/Walms/gnuCashTools>`__ by Walms (last updated on  2017-07-17)
	Just a few scripts to help manage my budget
`gnucashxml <https://github.com/jorgenschaefer/gnucashxml>`__ by jorgenschaefer (last updated on  2017-02-05)
	New Maintainer, please use their repository
\* `hackerspace-gnucash <https://github.com/cvonkleist/hackerspace-gnucash>`__ by cvonkleist (last updated on  2015-01-06)
	Gainesville Hackerspace GnuCash scripts, etc.
`importfindata <https://github.com/gregorias/importfindata>`__ by gregorias (last updated on  2017-06-25)
	Script that updates Polish investment fund quotes in a Gnucash file.
\* `ing2gnucash <https://github.com/hjmeijer/ing2gnucash>`__ by hjmeijer (last updated on  2013-10-29)
	Converts downloaded ING (bank) transaction CSV files to GNUCash importable CSV
`ing2qif <https://github.com/marijnvriens/ing2qif>`__ by marijnvriens (last updated on  2017-10-07)
	Import ING bank statements and convert them to qif for importing into gnucash
`ing2qif2 <https://github.com/tychobismeijer/ing2qif2>`__ by tychobismeijer (last updated on  2017-03-13)
	Convert ING csv to QIF format for GnuCash
`jeffs-gnucash-utils <https://github.com/n1ywb/jeffs-gnucash-utils>`__ by n1ywb (last updated on  2016-12-13)
	Jeff Laughlin's Python utilities for GnuCash. Includes HTML invoice generator.
`koert <https://github.com/awesterb/koert>`__ by awesterb (last updated on  2017-03-19)
	Toolbox for the inspection of GnuCash (used by the financial control committee of Karpe Noktem).
\* `ledger2gnucash <https://github.com/forsetti/ledger2gnucash>`__ by forsetti (last updated on  2016-01-19)
	Simple python script to convert ledger-cli files to GnuCash
\* `masin <https://github.com/FelixAkk/masin>`__ by FelixAkk (last updated on  2013-12-28)
	A rework and GUI wrapping of the gcInvoice Python package for generating template based invoices from .gnucash data files.
\* `mbank2gnucash <https://github.com/h3xxx/mbank2gnucash>`__ by h3xxx (last updated on  2014-10-16)
	mBank transactions history to GnuCash converter
\* `mcash <https://github.com/mpharrigan2/mcash>`__ by mpharrigan2 (last updated on  2015-07-06)
	Investigate GNUCash 
`Mint2GNUCash <https://github.com/alexevans91/Mint2GNUCash>`__ by alexevans91 (last updated on  2017-03-04)
	Converts transaction CSV file from Mint.com to a format that can be imported into GNU Cash.
`mintcash <https://github.com/hiromu2000/mintcash>`__ by hiromu2000 (last updated on  2017-01-02)
	Transfer transactions from Mint.com to Gnucash
\* `NokiaCash <https://github.com/sunziping2016/NokiaCash>`__ by sunziping2016 (last updated on  2016-06-01)
	A GnuCash-like software on S60v3 developed by python
`ofxstatement <https://github.com/kedder/ofxstatement>`__ by kedder (last updated on  2017-09-26)
	Tool to convert proprietary bank statement to OFX format, suitable for importing to GnuCash.
`piecash <https://github.com/sdementen/piecash>`__ by sdementen (last updated on  2017-07-21)
	Pythonic interface to GnuCash SQL documents
`PyBank <https://github.com/dougthor42/PyBank>`__ by dougthor42 (last updated on  2017-03-09)
	Personal accounting software. Alternative to the likes of Quicken, iBank, Mint.com, and GnuCash
`pygnclib <https://github.com/tdf/pygnclib>`__ by tdf (last updated on  2016-12-04)
	Pyxb-based read and write support for GnuCash XML files
`pygnucash <https://github.com/MatzeB/pygnucash>`__ by MatzeB (last updated on  2017-09-03)
	Python code to read gnucash 2.6 sqlite3 files
`qifqif <https://github.com/Kraymer/qifqif>`__ by Kraymer (last updated on  2017-09-29)
	Enrich your .QIF files with categories
`rabobank-gnucash-converter <https://github.com/LvanWissen/rabobank-gnucash-converter>`__ by LvanWissen (last updated on  2017-01-26)
	(No description available)
`scripts <https://github.com/frinkelpi/scripts>`__ by frinkelpi (last updated on  2017-05-12)
	Collection of Python scripts
`text-messaging-to-gnucash <https://github.com/chrisbrasington/text-messaging-to-gnucash>`__ by chrisbrasington (last updated on  2016-12-05)
	Create transactions via commandline text-messaging to gnucash sqlite database.
\* `Timetracker-to-Gnucash-Invoice <https://github.com/EvansMike/Timetracker-to-Gnucash-Invoice>`__ by EvansMike (last updated on  2015-02-06)
	Takes Anuko Timetracker data and creates an Invoice in GnuCash
\* `tws-gnucash <https://github.com/timwswanson/tws-gnucash>`__ by timwswanson (last updated on  2014-03-29)
	(No description available)
\* `visa-parser <https://github.com/pguridi/visa-parser>`__ by pguridi (last updated on  2015-11-04)
	A parser for the Visa pdf bill from www.visa.com.ar, useful for CSV import in Gnucash.

.. _Awk:

Awk
---

\* `ibank2qif <https://github.com/tomszilagyi/ibank2qif>`__ by tomszilagyi (last updated on  2015-04-01)
	Bank account transactions into GnuCash

.. _C:

C
-

\* `gnucash-aqplus <https://github.com/jhs-s/gnucash-aqplus>`__ by jhs-s (last updated on  2014-05-02)
	Usually contains some fixes for aqbanking for GnuCash
\* `gnucash-svn <https://github.com/cstim/gnucash-svn>`__ by cstim (last updated on  2014-04-14)
	another clone of gnucash, but this time not using github's clone, and therefore keeping the svn metadata

.. _C#:

C#
--

\* `FinanceWeb <https://github.com/elohmeier/FinanceWeb>`__ by elohmeier (last updated on  2016-07-09)
	C#/.NET OData Adapter for reading GnuCash Databases with MSFT Excel
\* `gnucash2ledger-cli <https://github.com/marek-g/gnucash2ledger-cli>`__ by marek-g (last updated on  2014-08-05)
	Gnucash (general ledger html report) to ledger-cli converter.
\* `GnuCashParser <https://github.com/nikitazu/GnuCashParser>`__ by nikitazu (last updated on  2015-06-23)
	.Net parser for GnuCash files format
\* `GnuCashSharp <https://github.com/rstarkov/GnuCashSharp>`__ by rstarkov (last updated on  2016-10-05)
	A library for reading data from GnuCash XML files.

.. _C++:

C++
---

\* `gnucash-butchered <https://github.com/iulianu/gnucash-butchered>`__ by iulianu (last updated on  2015-12-04)
	My own butchered version of Gnucash
`UnderBudget <https://github.com/vimofthevine/UnderBudget>`__ by vimofthevine (last updated on  2016-11-22)
	Advanced personal budget analysis application that integrates with GnuCash, Quicken, mint.com, etc.

.. _CoffeeScript:

CoffeeScript
------------

\* `gnucash-viewer <https://github.com/phjardas/gnucash-viewer>`__ by phjardas (last updated on  2016-02-15)
	(No description available)

.. _Cucumber:

Cucumber
--------

\* `commerzbank-csv4gnucash <https://github.com/kisp/commerzbank-csv4gnucash>`__ by kisp (last updated on  2016-04-25)
	Tweak CSV exports from commerzbank for importing into GnuCash.

.. _Diff:

Diff
----

\* `GnuCash-Windows-Fixes <https://github.com/theochino/GnuCash-Windows-Fixes>`__ by theochino (last updated on  2015-03-19)
	Pieces needed to Compile Gnu Cash on a Windows machine ... http://wiki.gnucash.org/wiki/User:Bilkusg

.. _F#:

F#
--

\* `gnucash-tools <https://github.com/cantsin/gnucash-tools>`__ by cantsin (last updated on  2015-06-01)
	(No description available)

.. _Gettext Catalog:

Gettext Catalog
---------------

\* `gnucash-el <https://github.com/pgaval/gnucash-el>`__ by pgaval (last updated on  2015-03-14)
	Automatically exported from code.google.com/p/gnucash-el

.. _Go:

Go
--

`gnucash-viewer <https://github.com/mmbros/gnucash-viewer>`__ by mmbros (last updated on  2016-12-19)
	A gnucash file viewer
`gnucash-viewer-old <https://github.com/mmbros/gnucash-viewer-old>`__ by mmbros (last updated on  2016-12-19)
	(No description available)
\* `gocash <https://github.com/remyoudompheng/gocash>`__ by remyoudompheng (last updated on  2016-01-20)
	gocash is a personal accounting interface similar to gnucash

.. _Groovy:

Groovy
------

\* `Zio-Antunello <https://github.com/masokotanga/Zio-Antunello>`__ by masokotanga (last updated on  2013-10-13)
	un gnucash online (?)

.. _HTML:

HTML
----

\* `BackupGnuCashLinux <https://github.com/goodvibes2/BackupGnuCashLinux>`__ by goodvibes2 (last updated on  2016-06-02)
	Backup GnuCash for Linux (using openjdk + openjfx)
`gnucash-htdocs <https://github.com/Gnucash/gnucash-htdocs>`__ by Gnucash (last updated on  2017-08-16)
	GnuCash website.
\* `gnucash-jp <https://github.com/omoshetech/gnucash-jp>`__ by omoshetech (last updated on  2016-10-07)
	(No description available)
`gnucashkr.github.io <https://github.com/GnucashKr/gnucashkr.github.io>`__ by GnucashKr (last updated on  2017-05-06)
	gnucashkr.github.io 홈페이지 소스

.. _Haskell:

Haskell
-------

\* `hGnucash <https://github.com/pharaun/hGnucash>`__ by pharaun (last updated on  2016-01-18)
	Haskell xml library for parsing the gnucash file format
\* `hs-gnucash <https://github.com/knupfer/hs-gnucash>`__ by knupfer (last updated on  2015-07-07)
	Haskell library to work with gnucash

.. _Java:

Java
----

`accounting <https://github.com/milanogc/accounting>`__ by milanogc (last updated on  2017-01-23)
	This project is an attempt to create a GnuCash like system, i.e. it adopts the double entry bookkeeping accounting system, for the management of personal finances.
`androidcash <https://github.com/mbarbon/androidcash>`__ by mbarbon (last updated on  2017-05-23)
	Simple Android GnuCash companion
`barx <https://github.com/pgiu/barx>`__ by pgiu (last updated on  2017-06-20)
	Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
\* `barxm <https://github.com/pgiu/barxm>`__ by pgiu (last updated on  2015-03-05)
	Exportador de la información del estado de cuenta de Banco Galicia a CSV/QIF para usar en MoneyManagerEx, GnuCash, etc.
\* `BudgetReportGnuCash <https://github.com/martinlong1978/BudgetReportGnuCash>`__ by martinlong1978 (last updated on  2014-04-23)
	Jasper Budget Report for GnuCash
\* `convert-ingcsv-to-gnucash <https://github.com/jonaskoperdraat/convert-ingcsv-to-gnucash>`__ by jonaskoperdraat (last updated on  2016-06-16)
	Application to convert csv export from ING to a format GnuCash can import
\* `gcchart <https://github.com/jhogan/gcchart>`__ by jhogan (last updated on  2015-06-19)
	An website for reading GnuCash datasources and creating charts written in Java.
\* `gnc4a <https://github.com/bwduncan/gnc4a>`__ by bwduncan (last updated on  2014-11-22)
	GnuCash Companion for Android is an mobile application for devices running Google’s Android operating system, which will enable the users of GnuCash to do small things like adding a transaction or creating an invoice or expense voucher on the go.
\* `gnc4a <https://github.com/glennji/gnc4a>`__ by glennji (last updated on  2013-10-20)
	Gnucash for Android
\* `GncImport <https://github.com/fcuenca/GncImport>`__ by fcuenca (last updated on  2016-07-27)
	GnuCash transaction import tool
\* `GncXmlLib <https://github.com/fcuenca/GncXmlLib>`__ by fcuenca (last updated on  2015-11-12)
	A small library to manipulate GnuCash data in XML format
\* `GnuCash-2.6.5-importer <https://github.com/jan438/GnuCash-2.6.5-importer>`__ by jan438 (last updated on  2015-02-02)
	(No description available)
`gnucash-android <https://github.com/codinguser/gnucash-android>`__ by codinguser (last updated on  2017-10-08)
	Gnucash for Android mobile companion application. 
`gnucash-android-master <https://github.com/lucifa7/gnucash-android-master>`__ by lucifa7 (last updated on  2017-07-14)
	(No description available)
`gnucash-merge <https://github.com/pnemonic78/gnucash-merge>`__ by pnemonic78 (last updated on  2017-05-10)
	Merge two gnucash XML files.
\* `GnuCashBudgetReport <https://github.com/bvitale/GnuCashBudgetReport>`__ by bvitale (last updated on  2015-02-16)
	A budget report for GnuCash data that is stored in MySQL.
\* `gnucashMobile <https://github.com/nhrdl/gnucashMobile>`__ by nhrdl (last updated on  2013-10-19)
	(No description available)
\* `GnuCashToQIF <https://github.com/davidkgerman/GnuCashToQIF>`__ by davidkgerman (last updated on  2013-11-29)
	(No description available)
\* `GnuCashViewer <https://github.com/jrmcsoftware/GnuCashViewer>`__ by jrmcsoftware (last updated on  2016-01-12)
	GnuCash Viewer
\* `IngAusOfxFixLinux <https://github.com/goodvibes2/IngAusOfxFixLinux>`__ by goodvibes2 (last updated on  2016-07-29)
	ING Australia OFX Fix for Linux - Fix OFX file before importing into GnuCash
\* `javacash <https://github.com/nhrdl/javacash>`__ by nhrdl (last updated on  2013-08-09)
	Yet another implementation of gnucash in Java
`jcash <https://github.com/Ccook/jcash>`__ by Ccook (last updated on  2017-01-28)
	The missing Java API for GNUCash
\* `jgnucashlib <https://github.com/tdf/jgnucashlib>`__ by tdf (last updated on  2013-09-28)
	jGnucashLib - a java access to GnuCash files
`Maakboekingen <https://github.com/zwijze/Maakboekingen>`__ by zwijze (last updated on  2016-12-10)
	Maakboekingen in gnucash
\* `nordea-to-gnucash <https://github.com/mohamedamer/nordea-to-gnucash>`__ by mohamedamer (last updated on  2013-12-08)
	(No description available)
\* `workspace_gnucash <https://github.com/won21kr1/workspace_gnucash>`__ by won21kr1 (last updated on  2014-04-16)
	(No description available)

.. _JavaScript:

JavaScript
----------

\* `BackupGnuCashWin <https://github.com/goodvibes2/BackupGnuCashWin>`__ by goodvibes2 (last updated on  2016-05-31)
	Backup GnuCash for Windows (using javafx)
\* `bcqif <https://github.com/hugozap/bcqif>`__ by hugozap (last updated on  2015-09-23)
	Script simple para generar archivos QIF a partir de archivos .txt exportados desde Bancolombia y poder cargar los registros a programas como GnuCash
\* `finance_dashboard <https://github.com/manicolosi/finance_dashboard>`__ by manicolosi (last updated on  2015-05-20)
	A dashing dashboard to show financial information from GnuCash
`gnu-docs <https://github.com/mtuchi/gnu-docs>`__ by mtuchi (last updated on  2017-06-18)
	:sparkles: Awesome GnuCash Docs 
`gnucash-django <https://github.com/nylen/gnucash-django>`__ by nylen (last updated on  2017-09-06)
	Simple Web frontend for GnuCash, using Django
\* `gnucash-ext <https://github.com/matthewbednarski/gnucash-ext>`__ by matthewbednarski (last updated on  2015-05-30)
	(No description available)
`gnucash-price-importer <https://github.com/cortopy/gnucash-price-importer>`__ by cortopy (last updated on  2017-07-09)
	Script for importing historic currency prices into gnucash
`gnucash-reporter <https://github.com/AaronLenoir/gnucash-reporter>`__ by AaronLenoir (last updated on  2017-02-17)
	Visualizes some reports on GnuCash data.
\* `gnucash-reporting-view <https://github.com/MeerkatLabs/gnucash-reporting-view>`__ by MeerkatLabs (last updated on  2015-09-30)
	Angular JS Based viewer for gnucash-reports
\* `gnucash-viewer <https://github.com/drjeep/gnucash-viewer>`__ by drjeep (last updated on  2014-05-02)
	Web viewer for Gnucash using Python/Flask
\* `gnucash-web <https://github.com/mrkrstphr/gnucash-web>`__ by mrkrstphr (last updated on  2014-01-29)
	(No description available)
`GnucashReportingNVD3 <https://github.com/sholly/GnucashReportingNVD3>`__ by sholly (last updated on  2017-06-27)
	NVD3 frontend/playground for gnucash reporting..
`googcash <https://github.com/crazyh/googcash>`__ by crazyh (last updated on  2017-02-06)
	Simple Google Sheets replacement for GnuCash
\* `IngAusOfxFixWin <https://github.com/goodvibes2/IngAusOfxFixWin>`__ by goodvibes2 (last updated on  2016-07-29)
	ING Australia OFX Fix for Windows - Fix OFX file before importing into GnuCash
`profitcash-restful <https://github.com/TheProfitwareGroup/profitcash-restful>`__ by TheProfitwareGroup (last updated on  2017-07-11)
	[DEPRECATED] ProfitCash-RESTful is a RESTful service providing accounts and transaction information based on imported from GnuCash into MongoDB data.
`qif-converter <https://github.com/math1985/qif-converter>`__ by math1985 (last updated on  2017-10-07)
	Converts CSV files from ING (Netherlands) and BCEE (Luxembourg) into QIF files. Suitable for GnuCash.
`remotegnucash <https://github.com/justinhunt1223/remotegnucash>`__ by justinhunt1223 (last updated on  2016-12-03)
	Remote GnuCash
\* `skilap <https://github.com/sergeyksv/skilap>`__ by sergeyksv (last updated on  2016-08-20)
	Personal online applications, GnuCash clone and others

.. _Jupyter Notebook:

Jupyter Notebook
----------------

\* `gnucash-playground <https://github.com/nlzimmerman/gnucash-playground>`__ by nlzimmerman (last updated on  2016-08-15)
	Just playing around with OFX and gnucash files; I am presumably the only person who cares about this sort of things.
\* `gnucash_analysis <https://github.com/prattmic/gnucash_analysis>`__ by prattmic (last updated on  2016-06-02)
	Analyze GnuCash data with Pandas
`py-gnucash <https://github.com/ihkihk/py-gnucash>`__ by ihkihk (last updated on  2017-05-10)
	Python scripts for analysis of gnucash database

.. _PHP:

PHP
---

\* `buchungen <https://github.com/jungepiraten/buchungen>`__ by jungepiraten (last updated on  2016-09-12)
	Webinterface für gnucash-Datenbank mit Funktion zum Verifizieren von Buchungen
`cash-manager <https://github.com/jUnG3/cash-manager>`__ by jUnG3 (last updated on  2017-01-14)
	(No description available)
\* `cashonline-php-server <https://github.com/okovalov/cashonline-php-server>`__ by okovalov (last updated on  2014-10-07)
	Backend part for cashonline project (clone of gnucash)
`gnucash-eloquent <https://github.com/b3it/gnucash-eloquent>`__ by b3it (last updated on  2016-11-09)
	Laravel Eloquent Models for the GnuCash MySQL Backend
\* `gnucash-laravel <https://github.com/xstat/gnucash-laravel>`__ by xstat (last updated on  2015-12-21)
	(No description available)
\* `gnucash-php <https://github.com/cebe/gnucash-php>`__ by cebe (last updated on  2016-04-02)
	A library for reading gnucash XML format in PHP
`gnucash-reports <https://github.com/xstat/gnucash-reports>`__ by xstat (last updated on  2017-07-30)
	(No description available)
\* `gnucash-tools <https://github.com/cccmzwi/gnucash-tools>`__ by cccmzwi (last updated on  2015-02-16)
	Convert your onlinebanking-export (CSV) to a neatly pre-categorized QIF-File which can be imported in Quicken or Gnucash
\* `gnucash.cakephp <https://github.com/claudineimatos/gnucash.cakephp>`__ by claudineimatos (last updated on  2014-06-25)
	(No description available)
\* `gnucashreports <https://github.com/pedroabel/gnucashreports>`__ by pedroabel (last updated on  2015-02-16)
	Set of custom reports that I use for my personal finances. To see the reports working on a sample database, check the website http://gnucashreports.comuf.com/ ATTENTION: many problems yet. Many bugs that did not happen in my computer happened in this sample server.
\* `php-gnucash <https://github.com/mrkrstphr/php-gnucash>`__ by mrkrstphr (last updated on  2014-01-01)
	(No description available)
`ThinkopenAt.Gnucash <https://github.com/kraftb/ThinkopenAt.Gnucash>`__ by kraftb (last updated on  2017-04-07)
	A TYPO3 Flow package which allows to interface the Gnucash book keeping application

.. _PLSQL:

PLSQL
-----

\* `gnucash-mysql-additions <https://github.com/ohingardail/gnucash-mysql-additions>`__ by ohingardail (last updated on  2016-07-20)
	Custom MySql functions to add useful functions to GnuCash

.. _Perl:

Perl
----

`bsestocks <https://github.com/poomalairaj/bsestocks>`__ by poomalairaj (last updated on  2017-06-07)
	Perl module to fetch live price from Bombay Stock Exchange (BSE) for Gnucash Finance
`budgetProgram <https://github.com/Beahmer89/budgetProgram>`__ by Beahmer89 (last updated on  2016-10-23)
	Converts GNUCash programs xml output to csv file to see monthly/yearly spending habits
`Finance--Quote--YahooJapan <https://github.com/LiosK/Finance--Quote--YahooJapan>`__ by LiosK (last updated on  2017-01-18)
	Finance::Quote::YahooJapan - A Perl module that enables GnuCash to get quotes of Japanese stocks and mutual funds from Yahoo! Finance JAPAN.
`finance-bomse <https://github.com/abhijit86k/finance-bomse>`__ by abhijit86k (last updated on  2017-09-11)
	A Perl module for fetching quotes for Indian stocks, intended for use with gnucash
`finance-quote-brazil <https://github.com/romuloceccon/finance-quote-brazil>`__ by romuloceccon (last updated on  2017-06-12)
	Gnucash/Finance::Quote modules to fetch prices of Brazilian bonds and mutual funds
`FinanceQuoteBr <https://github.com/ailtonljr/FinanceQuoteBr>`__ by ailtonljr (last updated on  2017-09-08)
	Perl Finance Quote modules for Brazilian market. Original files from https://lists.gnucash.org/pipermail/gnucash-br/2016-November/000535.html
\* `gc2latex <https://github.com/wertarbyte/gc2latex>`__ by wertarbyte (last updated on  2015-02-16)
	create pretty Gnucash invoices with LaTeX and Perl
\* `GnuCash-Branch <https://github.com/LiosK/GnuCash-Branch>`__ by LiosK (last updated on  2015-04-26)
	GnuCash::Branch - Utilities to implement branch accounting with GnuCash.
\* `gnucash-extensions <https://github.com/tomason/gnucash-extensions>`__ by tomason (last updated on  2016-09-28)
	(No description available)
\* `gnucash-importer <https://github.com/AloisMahdal/gnucash-importer>`__ by AloisMahdal (last updated on  2014-09-09)
	Import CSV data from arbitrary bank format to CSV acceptable by GnuCash
\* `gnucash-monthly-budget-report <https://github.com/mhodapp/gnucash-monthly-budget-report>`__ by mhodapp (last updated on  2015-03-01)
	perl program to generate monthly budget reports
\* `GnuCash-MySQL <https://github.com/theochino/GnuCash-MySQL>`__ by theochino (last updated on  2015-03-18)
	A MySQL module to Gnu Cash
`gnucash-perl <https://github.com/goblin/gnucash-perl>`__ by goblin (last updated on  2016-11-01)
	Perl modules for reading and writing the Gnucash XML file
`gnucash-quote-sources <https://github.com/tjol/gnucash-quote-sources>`__ by tjol (last updated on  2017-04-23)
	Some useful methods to fetch market price data for GnuCash
\* `GnuCash-SQLite <https://github.com/hoekit/GnuCash-SQLite>`__ by hoekit (last updated on  2015-01-25)
	A perl module to access GnuCash SQLite files.
\* `GnuCash-SQLite <https://github.com/gitpan/GnuCash-SQLite>`__ by gitpan (last updated on  2015-01-08)
	Read-only release history for GnuCash-SQLite
\* `gnucash-summarizer <https://github.com/Nazrax/gnucash-summarizer>`__ by Nazrax (last updated on  2016-05-06)
	(No description available)
`gnucash2mysql <https://github.com/xaprb/gnucash2mysql>`__ by xaprb (last updated on  2017-01-13)
	Gnucash to MySQL export script.
`gnucash2mysql_extras <https://github.com/hmackiernan/gnucash2mysql_extras>`__ by hmackiernan (last updated on  2016-12-02)
	Extra scripts and bits for gnucash2mysql
\* `gnuCash_Quote <https://github.com/z-Wind/gnuCash_Quote>`__ by z-Wind (last updated on  2016-01-06)
	modify perl\site\lib\Finance\Quote.pm
\* `MoneyDance-GnuCash-Importer <https://github.com/ets/MoneyDance-GnuCash-Importer>`__ by ets (last updated on  2016-02-27)
	Script to convert GnuCash data into a native MoneyDance XML file format
\* `Paypal-csv-to-qif-converter <https://github.com/sonologic/Paypal-csv-to-qif-converter>`__ by sonologic (last updated on  2014-09-08)
	Converts paypal .csv to qif for importing in gnucash
\* `perl-gnucash-reader <https://github.com/hoekit/perl-gnucash-reader>`__ by hoekit (last updated on  2014-09-09)
	(No description available)
`PerlFinanceQuoteBloomberg <https://github.com/alex314159/PerlFinanceQuoteBloomberg>`__ by alex314159 (last updated on  2017-09-26)
	Bloomberg module for the Perl Finance::Quote module (used in particular by GnuCash)
\* `query_gnucash_db <https://github.com/hmackiernan/query_gnucash_db>`__ by hmackiernan (last updated on  2016-08-20)
	Perl script to query a MySQL db created by the 'gnucash2mysql' script
\* `tikzdipa <https://github.com/vimdude/tikzdipa>`__ by vimdude (last updated on  2014-12-21)
	GnuCash online quote source using Yahoo api

.. _Perl 6:

Perl 6
------

`gnucashfinancequote <https://github.com/vimdude/gnucashfinancequote>`__ by vimdude (last updated on  2017-08-19)
	Gnucash quote using Google Finance
`MumbaiStock <https://github.com/geetuvaswani/MumbaiStock>`__ by geetuvaswani (last updated on  2017-08-25)
	MumbaiStock - A perl module for Finance::Quotes that fetches the day end price list from Bombay Stock Exchange into GnuCash

.. _Perl6:

Perl6
-----

\* `perl6-gnucash <https://github.com/eikef/perl6-gnucash>`__ by eikef (last updated on  2016-08-14)
	Use gnucash library from Perl 6

.. _R:

R
-

\* `GnuCashConverter <https://github.com/ms32035/GnuCashConverter>`__ by ms32035 (last updated on  2015-09-12)
	R package to convert transaction history files from Polish banks to GnuCash importable CSVs
`ShinyBudgetAnalysis <https://github.com/paulheider/ShinyBudgetAnalysis>`__ by paulheider (last updated on  2017-03-08)
	A Shiny app (R-based dashboard) that gives insight into your GnuCash budget habits over time.

.. _Ruby:

Ruby
----

\* `accounting <https://github.com/freegeek-pdx/accounting>`__ by freegeek-pdx (last updated on  2013-12-04)
	accounting utilities for xtuple import and allocation in xtuple and gnucash
`arges <https://github.com/isimluk/arges>`__ by isimluk (last updated on  2017-01-15)
	Calc roe from gnucash transaction log
`cnab2ofx <https://github.com/abinoam/cnab2ofx>`__ by abinoam (last updated on  2017-02-14)
	CNAB240 to OFX conversion script
`dnbnor2qif <https://github.com/kentdahl/dnbnor2qif>`__ by kentdahl (last updated on  2017-01-04)
	dnbnor2qif is a simple tool to help integrate data from the DnBNOR online bank monthly transcripts ("kontoutskrift") to a QIF accepting financial program, i.e. GnuCash.
`gnucash-invoice <https://github.com/ixti/gnucash-invoice>`__ by ixti (last updated on  2016-11-05)
	Easy to use invoice printer for GnuCash.
\* `gnucash-rb <https://github.com/vbatts/gnucash-rb>`__ by vbatts (last updated on  2013-09-18)
	Ruby access to Gnucash SQL database
`gnucash2bmd <https://github.com/ngiger/gnucash2bmd>`__ by ngiger (last updated on  2017-05-22)
	Convert GnuCash CSV files into CSV which can be read by http://www.bmd.com/
\* `gnucash2ledger <https://github.com/xaviershay/gnucash2ledger>`__ by xaviershay (last updated on  2015-03-06)
	Convert GnuCash files to a format supported by the ledger command line application
\* `gnucash_export <https://github.com/alibby/gnucash_export>`__ by alibby (last updated on  2013-12-01)
	Export gnucash data to sqlite/ csv
\* `nyancash <https://github.com/hanazuki/nyancash>`__ by hanazuki (last updated on  2016-09-28)
	Ruby to GnuCash database binding
`ruby-gnucash <https://github.com/holtrop/ruby-gnucash>`__ by holtrop (last updated on  2017-10-06)
	Ruby library for extracting data from GnuCash data files
`vfwcash <https://github.com/salex/vfwcash>`__ by salex (last updated on  2017-05-01)
	A Ruby CLI application that produces PDF reports from GnuCash

.. _SQLPL:

SQLPL
-----

`gnucash-tools <https://github.com/schoettl/gnucash-tools>`__ by schoettl (last updated on  2017-02-21)
	Collection of tools to work with GnuCash efficiently

.. _Scala:

Scala
-----

\* `gnucash-quotes <https://github.com/akorneev/gnucash-quotes>`__ by akorneev (last updated on  2014-12-20)
	(No description available)
\* `gnucash-stuff <https://github.com/crankydillo/gnucash-stuff>`__ by crankydillo (last updated on  2014-01-18)
	(No description available)
`GnuCashExtractor <https://github.com/Winbee/GnuCashExtractor>`__ by Winbee (last updated on  2017-06-04)
	Extract data from gnuCash and copy it into an open document spreadsheet

.. _Scheme:

Scheme
------

\* `gc-decl-reports <https://github.com/yawaramin/gc-decl-reports>`__ by yawaramin (last updated on  2014-02-09)
	GnuCash declarative reports
`gnucash-account-balance-chart <https://github.com/timabell/gnucash-account-balance-chart>`__ by timabell (last updated on  2016-10-10)
	account balance line chart for gnucash
\* `gnucash-custom-reports <https://github.com/BenBergman/gnucash-custom-reports>`__ by BenBergman (last updated on  2016-04-01)
	(No description available)
`gnucash-multicolumn <https://github.com/christopherlam/gnucash-multicolumn>`__ by christopherlam (last updated on  2017-04-03)
	Advanced date and text filtering and multicolumn reports
\* `gnucash-reports <https://github.com/trailbound/gnucash-reports>`__ by trailbound (last updated on  2015-11-05)
	Custom set of gnucash reports, currently in development.
`gnucash-reports <https://github.com/jaminh/gnucash-reports>`__ by jaminh (last updated on  2017-04-04)
	Reports for personal finance using gnucash
\* `gnucash-reports <https://github.com/dschwen/gnucash-reports>`__ by dschwen (last updated on  2016-01-27)
	Custom reports for Gnucash
\* `gnucash-reports <https://github.com/cnuahs/gnucash-reports>`__ by cnuahs (last updated on  2015-12-28)
	Custom reports for use with GnuCash (http://gnucash.org/).
`gnucash-reports <https://github.com/wentzel/gnucash-reports>`__ by wentzel (last updated on  2016-10-26)
	Some nice reports for GnuCash
\* `gnucash-statement-table <https://github.com/waldeinburg/gnucash-statement-table>`__ by waldeinburg (last updated on  2016-01-13)
	GnuCash report with cash flow over time
\* `gnucashportable <https://github.com/GordCaswell/gnucashportable>`__ by GordCaswell (last updated on  2016-01-12)
	GnuCash packaged in PortableApps.com Format
\* `GnuCashReports <https://github.com/wlcasper/GnuCashReports>`__ by wlcasper (last updated on  2015-07-19)
	Custom Reports for GnuCash
\* `ibr-gnc-module <https://github.com/ErwinRieger/ibr-gnc-module>`__ by ErwinRieger (last updated on  2016-04-04)
	GnuCash Erweiterungen für deutsche Buchhaltung

.. _Shell:

Shell
-----

`AccountsConvertToGnucash <https://github.com/tontako/AccountsConvertToGnucash>`__ by tontako (last updated on  2016-12-23)
	Convert Kakeibo(Android Application) CSV exports to QIF format (usable by GnuCash and others) 
\* `archlinux-gnucash-latest <https://github.com/nengxu/archlinux-gnucash-latest>`__ by nengxu (last updated on  2015-03-31)
	Archlinux AUR package building scripts for latest Gnucash
`docker-gnucash-novnc <https://github.com/bertlorenz/docker-gnucash-novnc>`__ by bertlorenz (last updated on  2017-08-21)
	(No description available)
\* `gnucash-csv-import <https://github.com/thomasramapuram/gnucash-csv-import>`__ by thomasramapuram (last updated on  2016-08-08)
	(No description available)
\* `gnucash-cubes <https://github.com/leo90skk/gnucash-cubes>`__ by leo90skk (last updated on  2016-09-04)
	A OLAP database model for a mysql based GnuCash installation.
\* `gnucash-devel <https://github.com/aur-archive/gnucash-devel>`__ by aur-archive (last updated on  2015-08-15)
	(No description available)
`gnucash-docker <https://github.com/limitedAtonement/gnucash-docker>`__ by limitedAtonement (last updated on  2017-01-27)
	docker image for repeatable gnucash builds.
\* `gnucash-docs <https://github.com/aur-archive/gnucash-docs>`__ by aur-archive (last updated on  2015-08-15)
	(No description available)
`gnucash-docs-old <https://github.com/yasuakit/gnucash-docs-old>`__ by yasuakit (last updated on  2017-07-02)
	Manual and User Guide for Gnucash, the open-source accounting program
\* `gnucash-hbci <https://github.com/aur-archive/gnucash-hbci>`__ by aur-archive (last updated on  2015-08-15)
	(No description available)
`gnucash-jz-snap <https://github.com/jacobzimmermann/gnucash-jz-snap>`__ by jacobzimmermann (last updated on  2017-08-30)
	(No description available)
\* `gnucash-on-fedora-copr <https://github.com/Gnucash/gnucash-on-fedora-copr>`__ by Gnucash (last updated on  2016-05-31)
	A set of build scripts geared towards creating rpm packages for gnucash and gnucash-docs on Fedora's Copr infrastructure. It's currently used to build nightly rpm packages for the maint and master branches intended for testing changes since the last release..
`gnucash-on-osx <https://github.com/jralls/gnucash-on-osx>`__ by jralls (last updated on  2017-05-11)
	Build GnuCash on OSX without X11
`gnucash-on-osx <https://github.com/Gnucash/gnucash-on-osx>`__ by Gnucash (last updated on  2017-06-16)
	Gtk-OSX moduleset, gtk-mac-bundler bundles, and ancillary files for creating GnuCash OSX Application Bundle.
`gnucash-on-windows <https://github.com/Gnucash/gnucash-on-windows>`__ by Gnucash (last updated on  2017-09-26)
	Support scripts to build gnucash for Windows using mingw32.
`gnucash-on-windows <https://github.com/gjanssens/gnucash-on-windows>`__ by gjanssens (last updated on  2017-01-26)
	Support scripts to build gnucash for Windows using mingw32.
\* `gnucash-python <https://github.com/aur-archive/gnucash-python>`__ by aur-archive (last updated on  2015-08-15)
	(No description available)
\* `gnucash-svn <https://github.com/aur-archive/gnucash-svn>`__ by aur-archive (last updated on  2015-08-15)
	(No description available)
`gnucash-util-jp <https://github.com/mikkun/gnucash-util-jp>`__ by mikkun (last updated on  2016-10-23)
	日本の商慣習下でGnuCashを使うためのツール
\* `gnucash.SlackBuild <https://github.com/botzkobg/gnucash.SlackBuild>`__ by botzkobg (last updated on  2015-04-02)
	SlackBuild script to compile GnuCash
\* `LittleBudget <https://github.com/kstripp/LittleBudget>`__ by kstripp (last updated on  2016-09-12)
	Little Budget Tool for GNUCash
\* `nordea2ofx <https://github.com/nsrosenqvist/nordea2ofx>`__ by nsrosenqvist (last updated on  2014-10-24)
	A quick implementation of a converter between Nordea's CSV export to OFX so that it can be imported into various applications, such as Homebank or GnuCash. Only supporting Swedish and my edge cases, please consider improving the script and send a pull request for the changes.
\* `TW5-GNUCash-Assistant <https://github.com/JulioCantarero/TW5-GNUCash-Assistant>`__ by JulioCantarero (last updated on  2016-03-12)
	A custom edition of TiddlyWiki5 designed to collect financial information from your banks and export them in QIF format

.. _Swift:

Swift
-----

`cash <https://github.com/cjwirth/cash>`__ by cjwirth (last updated on  2017-06-26)
	iOS companion app for GnuCash

.. _Tcl:

Tcl
---

`pycash <https://github.com/EvansMike/pycash>`__ by EvansMike (last updated on  2017-06-12)
	Some Python utilites that GnuCash users may find useful.

.. _TypeScript:

TypeScript
----------

`web-cash <https://github.com/nulldev07/web-cash>`__ by nulldev07 (last updated on  2017-05-21)
	Web version of GnuCash

.. _Visual Basic:

Visual Basic
------------

`OneClickToQif <https://github.com/OneClickToQif/OneClickToQif>`__ by OneClickToQif (last updated on  2017-09-23)
	OneClickToQIF consists of a set of templates and macros, which are used to export data from your spreadsheets to QIF format, as used by programs such as GnuCash, Money and Quicken. You can use the templates as provided, or adapt your own spreadsheet, so your data is automatically exported to QIF with a single click.

.. _XSLT:

XSLT
----

`gnucash-docs <https://github.com/Gnucash/gnucash-docs>`__ by Gnucash (last updated on  2017-08-20)
	Documentation for GnuCash Accounting Program.

.. _Unknown:

Unknown
-------

\* `accounting <https://github.com/communotey/accounting>`__ by communotey (last updated on  2016-10-05)
	:moneybag: Accounting for Communote, using GNUCash
\* `accounts <https://github.com/sjtug/accounts>`__ by sjtug (last updated on  2016-09-25)
	Accounts of SJTUG in GNUCash Format
\* `an-gnucash <https://github.com/wanjing/an-gnucash>`__ by wanjing (last updated on  2013-01-11)
	android app for gnucash
`ansible-role-gnucash <https://github.com/wtanaka/ansible-role-gnucash>`__ by wtanaka (last updated on  2017-07-08)
	Ansible role for installing gnucash
\* `CICtoGNUcash <https://github.com/jbtruffault/CICtoGNUcash>`__ by jbtruffault (last updated on  2016-06-15)
	(No description available)
`ComptaTest <https://github.com/palric/ComptaTest>`__ by palric (last updated on  2017-05-05)
	Exercices programmation python/panda: importation de fichiers comptas bancaires, formatage et importation dans GnuCash
`CPA-006-Asap-Cheques <https://github.com/dougransom/CPA-006-Asap-Cheques>`__ by dougransom (last updated on  2017-09-25)
	Gnucash Check Configurations to print on Canadian Cheques from ASAP Cheques.
`docker-gnucash <https://github.com/mbessler/docker-gnucash>`__ by mbessler (last updated on  2017-10-01)
	Containerized GnuCash
`docker-gnucash <https://github.com/mhitchens/docker-gnucash>`__ by mhitchens (last updated on  2017-04-16)
	GnuCash running via X11 over SSH
`docker-mobile-gnucash <https://github.com/au-phiware/docker-mobile-gnucash>`__ by au-phiware (last updated on  2016-12-18)
	Docker containers for justinhunt1223/mobilegnucash
\* `GCtranslate <https://github.com/AshokR/GCtranslate>`__ by AshokR (last updated on  2016-09-27)
	GnuCash Translation
\* `GnuCash-3part-check <https://github.com/agh1/GnuCash-3part-check>`__ by agh1 (last updated on  2013-10-17)
	A 3-part check format for GnuCash
\* `gnucash-api <https://github.com/jjuanda/gnucash-api>`__ by jjuanda (last updated on  2014-02-02)
	REST APIs for GnuCash files
\* `gnucash-auditfile <https://github.com/vylum/gnucash-auditfile>`__ by vylum (last updated on  2016-02-05)
	Creates a dutch Auditfile for tax purposes from a gnuCash datafile.
`gnucash-compose <https://github.com/daveyb/gnucash-compose>`__ by daveyb (last updated on  2017-03-11)
	docker-compose file(s) to bring up local gnucash cluster
\* `gnucash-data <https://github.com/anshprat/gnucash-data>`__ by anshprat (last updated on  2015-06-02)
	data files for my gnucash encrypted with gpg
\* `gnucash-docs <https://github.com/cygwinports/gnucash-docs>`__ by cygwinports (last updated on  2016-03-07)
	Cygwin gnucash-docs packaging
\* `gnucash-export <https://github.com/deonbredenhann/gnucash-export>`__ by deonbredenhann (last updated on  2014-06-19)
	Export GnuCash to csv
`gnucash-guide-gitbook <https://github.com/codesmythe/gnucash-guide-gitbook>`__ by codesmythe (last updated on  2017-06-02)
	The GnuCash Tutorial and Concept Guide, converted to Asciidoc for use in GitBook
`gnucash-queries <https://github.com/g2010a/gnucash-queries>`__ by g2010a (last updated on  2016-10-18)
	Queries to extract data from Gnucash's database
\* `gnucash-rest <https://github.com/mhitchens/gnucash-rest>`__ by mhitchens (last updated on  2014-05-03)
	A Spring Data/Spring REST interface to a gnucash data file
\* `gnucash-web <https://github.com/djbrown/gnucash-web>`__ by djbrown (last updated on  2016-01-01)
	(No description available)
`gnucash_auto <https://github.com/torchtarget/gnucash_auto>`__ by torchtarget (last updated on  2017-08-16)
	A simple transaction importer for Gnucash
\* `gnucashweb <https://github.com/AndersonLira/gnucashweb>`__ by AndersonLira (last updated on  2015-11-01)
	Web App Based on Grails like gnucash desktop
`knab-gnucash-converter <https://github.com/bkrijg/knab-gnucash-converter>`__ by bkrijg (last updated on  2017-05-03)
	A python script for converting KNAB bankstatement information files into a suitable gnucash csv import file
`mint2gnucash <https://github.com/SAL-e/mint2gnucash>`__ by SAL-e (last updated on  2017-04-05)
	Use mint.com together with GnuCash.
\* `nordea-csv2qif <https://github.com/martinolsen/nordea-csv2qif>`__ by martinolsen (last updated on  2014-06-11)
	Convert Nordea CSV exports to QIF format (usable by GnuCash and others)
`org.gnucash.GnuCash <https://github.com/flathub/org.gnucash.GnuCash>`__ by flathub (last updated on  2017-07-06)
	(No description available)
\* `PayPalConvert <https://github.com/rowantree/PayPalConvert>`__ by rowantree (last updated on  2015-11-04)
	Convert PayPal csv files to qif for loading into GnuCash
\* `rabo2qif <https://github.com/milovanderlinden/rabo2qif>`__ by milovanderlinden (last updated on  2015-09-03)
	export mut.txt to qif for gnucash

